@@ -1,12 +1,12 @@
-"""Define CLI arguments."""
+"""Definition of CLI arguments."""
+
 import argparse
 
-from normcap.data import DEFAULT_SETTINGS, DESCRIPTION
+from normcap.gui.constants import DEFAULT_SETTINGS, DESCRIPTION
 
 
 def create_argparser() -> argparse.ArgumentParser:
     """Parse command line arguments."""
-
     parser = argparse.ArgumentParser(prog="normcap", description=DESCRIPTION)
 
     for setting in DEFAULT_SETTINGS:
@@ -15,8 +15,8 @@ def create_argparser() -> argparse.ArgumentParser:
             f"--{setting.key}",
             type=setting.type_,
             help=setting.help,
+            choices=setting.choices,
         )
-
     parser.add_argument(
         "-r",
         "--reset",
@@ -26,16 +26,10 @@ def create_argparser() -> argparse.ArgumentParser:
     )
     parser.add_argument(
         "-v",
-        "--verbose",
-        action="store_true",
-        help="print debug information to console",
-        default=False,
-    )
-    parser.add_argument(
-        "-V",
-        "--very-verbose",
-        action="store_true",
-        help="print more debug information to console",
-        default=False,
+        "--verbosity",
+        default="warning",
+        action="store",
+        choices=["error", "warning", "info", "debug"],
+        help="set level of detail for console output (default: %(default)s)",
     )
     return parser
